export(seair_params)
export(seair_init)
export(seair_solve)
export(seair_aggregate)
export(R0_seair)
export(final_size)
export(final_size_general)
export(c_effective)
export(beta_mixture_density)
export(fit_mobility)
export(plot_seair)
importFrom(deSolve, ode)
importFrom(stats, dbeta, integrate, optim, uniroot)
importFrom(graphics, lines, matplot, legend)
